@@ -224,7 +224,7 @@ int AcqBuffer::saveToDisk(bool save)
 		tempFile = tmpfile();
 		if(tempFile == NULL)
 		{
-			cerr << "unable to open temporary file " << endl;
+			std::cerr << "unable to open temporary file " << std::endl;
 			return -1;
 		}
 	}
