@@ -33,7 +33,7 @@ class AcqBuffer;
 #include <stdlib.h>
 #include <comedilib.h>
 #include <zlib.h>
-#include <iostream.h>
+#include <iostream>
 
 #include "adc.h"
 #include "data.h"
@@ -75,7 +75,7 @@ inline ssize_t AcqBuffer::read(void *buffer, size_t size)
 		writeCount = fwrite(buffer, sizeof(sampl_t), readCount, tempFile);
 		if(writeCount != readCount)
 		{
-			cerr << "error writing data to temporary file, check for sufficient disk space" << endl;
+			std::cerr << "error writing data to temporary file, check for sufficient disk space" << std::endl;
 			exit(1);
 		}
 	}
