@@ -21,8 +21,8 @@
 
 #include <qmessagebox.h>
 
-#include <iostream.h>
-#include <fstream.h>
+#include <iostream>
+#include <fstream>
 #include <errno.h>
 #include <math.h>
 #include <time.h>
@@ -321,7 +321,7 @@ cleanup:
 		ret = system(prefix + localSettings.endCommand);	
 		if(ret)
 		{
-			cerr << "nonzero system() return value: " << ret << "  at end of aquisition" << endl;
+			std::cerr << "nonzero system() return value: " << ret << "  at end of aquisition" << std::endl;
 		}
 	}
 	if(aBuf)
@@ -336,7 +336,7 @@ cleanup:
 int KTTEngine::writeFiles(KTTSettings localSettings, AcqBuffer *aBuf)
 {
 	QString fileName, paramFileName;
-	ofstream paramFile;
+	std::ofstream paramFile;
 	int ret = 0;
 	time_t now;
 	/* this mutex exists to serialize file writing, when more than one thread calls
@@ -351,49 +351,49 @@ int KTTEngine::writeFiles(KTTSettings localSettings, AcqBuffer *aBuf)
 	paramFile.open(paramFileName);
 	if(!paramFile)
 	{
-		cerr << "error opening parameter save file" << endl;
+		std::cerr << "error opening parameter save file" << std::endl;
 		ret = -1;
 		goto cleanup;
 	}
-	paramFile << "[info]" << endl;
-	paramFile << "program=" << PACKAGE << endl;
-	paramFile << "version=" << VERSION << endl;
-	paramFile << "filename=" << fileName << endl;
-	paramFile << "hardware=" << localSettings.boardName << endl;
+	paramFile << "[info]" << std::endl;
+	paramFile << "program=" << PACKAGE << std::endl;
+	paramFile << "version=" << VERSION << std::endl;
+	paramFile << "filename=" << fileName << std::endl;
+	paramFile << "hardware=" << localSettings.boardName << std::endl;
 	now = time(NULL);
 	paramFile << "time stamp=" << asctime(localtime(&now));
-	paramFile << "[settings]" << endl;
-	paramFile << "scan trigger=" << adc::trigToText(localSettings.scanTrigger) << endl;
+	paramFile << "[settings]" << std::endl;
+	paramFile << "scan trigger=" << adc::trigToText(localSettings.scanTrigger) << std::endl;
 	if(localSettings.scanTrigger == TRIG_TIMER ||
 		(localSettings.conversionTrigger == TRIG_TIMER &&
 		localSettings.scanTrigger == TRIG_FOLLOW))
-		paramFile << "scan frequency=" << localSettings.scanFrequency << endl;
-	paramFile << "conversion trigger=" << adc::trigToText(localSettings.conversionTrigger) << endl;
+		paramFile << "scan frequency=" << localSettings.scanFrequency << std::endl;
+	paramFile << "conversion trigger=" << adc::trigToText(localSettings.conversionTrigger) << std::endl;
 	if(localSettings.conversionTrigger == TRIG_TIMER)
-		paramFile << "conversion frequency=" << localSettings.conversionFrequency << endl;
-	paramFile << "stop trigger=" << adc::trigToText(localSettings.stopTrigger) << endl;
+		paramFile << "conversion frequency=" << localSettings.conversionFrequency << std::endl;
+	paramFile << "stop trigger=" << adc::trigToText(localSettings.stopTrigger) << std::endl;
 	if(localSettings.stopTrigger == TRIG_COUNT)
-		paramFile << "scans requested=" << localSettings.numScans << endl;
-	paramFile << "scans completed=" << localSettings.numScansCompleted << endl;
-	paramFile << "number of channels=" << localSettings.numChannels << endl;
+		paramFile << "scans requested=" << localSettings.numScans << std::endl;
+	paramFile << "scans completed=" << localSettings.numScansCompleted << std::endl;
+	paramFile << "number of channels=" << localSettings.numChannels << std::endl;
 	paramFile << "input range=" << localSettings.rangeInfo.min << "," 
-		<< localSettings.rangeInfo.max << endl;
+		<< localSettings.rangeInfo.max << std::endl;
 	switch(localSettings.rangeInfo.unit)
 	{
 		case UNIT_volt:
-			paramFile << "input unit=volt" << endl;
+			paramFile << "input unit=volt" << std::endl;
 			break;
 		case UNIT_mA:
-			paramFile << "input unit=mA" << endl;
+			paramFile << "input unit=mA" << std::endl;
 			break;
 		default:
-			paramFile << "input unit=unknown" << endl;
+			paramFile << "input unit=unknown" << std::endl;
 			break;
 	}
-	paramFile << "input reference=" << adc::refToText(localSettings.reference) << endl;
+	paramFile << "input reference=" << adc::refToText(localSettings.reference) << std::endl;
 	if(paramFile.good() == false)
 	{
-		cerr << "error writing parameter file" << endl;
+		std::cerr << "error writing parameter file" << std::endl;
 		paramFile.close();
 		ret = -1;		
 		goto cleanup;
@@ -414,7 +414,7 @@ int KTTEngine::writeFiles(KTTSettings localSettings, AcqBuffer *aBuf)
 			ret = aBuf->writeBinaryFiles(fileName, localSettings.numChannels);
 			break;
 		default:
-			cerr << "save type not specified" << endl;
+			std::cerr << "save type not specified" << std::endl;
 			ret = -1;
 			goto cleanup;
 			break;
@@ -462,7 +462,7 @@ void KTTEngine::slotUpdatePlot()
 
 		// update progress bar
 		if(settings.stopTrigger == TRIG_COUNT)
-			view->setProgress((100.0 * (numPointsPlotted)) / (settings.numScans * settings.numChannels));
+			view->setProgress((int)((100.0 * (numPointsPlotted)) / (settings.numScans * settings.numChannels)));
 	}else
 		pthread_mutex_unlock(&dataFifoMutex);
 	
