@@ -22,6 +22,7 @@
 #include <qwhatsthis.h>
 
 #include <math.h>
+#include <cassert>
 
 #include "ktimetrace.h"
 
@@ -362,7 +363,7 @@ void  KTraceDialog::initDialog()
 
 	numScans = new QSpinBox(leftColumn);
 	numScans->move(stopTrigger->x(), stopTrigger->geometry().bottom() + vsep);
-	numScans->setRange(1, pow(2, 31) - 1);
+	numScans->setRange(1, INT_MAX);
 	numScans->adjustSize();
 	QWhatsThis::add(numScans, "The total number of scans to perform");
 
@@ -621,7 +622,7 @@ void KTraceDialog::slotRange(int rng)
 		settings->range = rng;
 	}else
 	{
-		cerr << "bug! cRange null" << endl;
+		std::cerr << "bug! cRange null" << std::endl;
 	}
 }
 
