@@ -26,7 +26,7 @@
 #include <qmessagebox.h>
 #include <qtimer.h>
 
-#include <iostream.h>
+#include <iostream>
 
 #include "dialog.h"
 #include "bufferdialog.h"
@@ -170,12 +170,12 @@ bool KTraceApp::queryExit()
 	// wait until all file writing threads have finished
 	if(data.writeDone() == false)
 	{
-		cerr << "waiting for data file save to complete..." << endl;
+		std::cerr << "waiting for data file save to complete..." << std::endl;
 		while(data.writeDone() == false)
 		{
 			usleep(100000);
 		}
-		cerr << "data save completed" << endl;
+		std::cerr << "data save completed" << std::endl;
 	}
 	// work-around for qt bug
 	exit(0);
